@@ -59,6 +59,10 @@ Here is what a profile file looks like::
                 # A fixed amount of data to send to the mouse (optional).
                 # This is required by some mice like the Rival 110.
                 "packet_length": 32,
+                # If greater that 0, the number of bytes to read from the
+                # device after the command. This is required by some wireless
+                # mice like the Aerox 3 Wireless in wireless mode.
+                "readback_length": 0,
                 # The type of value supported by this setting.
                 # See the `rivalcfg.handlers` documentation for more
                 # information.
@@ -145,8 +149,12 @@ Module API
 import os
 import types
 
+from . import aerox3  # noqa: F401
+from . import aerox3_wireless_wired  # noqa: F401
+from . import aerox3_wireless_wireless  # noqa: F401
 from . import kanav2  # noqa: F401
 from . import kinzuv2  # noqa: F401
+from . import prime  # noqa: F401
 from . import rival3  # noqa: F401
 from . import rival95  # noqa: F401
 from . import rival100  # noqa: F401
@@ -167,8 +175,7 @@ PROFILES = None
 
 
 class UnsupportedDevice(Exception):
-    """Exception raised when the requested device is not supported by rivalcfg.
-    """
+    """Exception raised when the requested device is not supported by rivalcfg."""
 
 
 def list_plugged_devices():
@@ -187,22 +194,20 @@ def list_plugged_devices():
     """
     if "RIVALCFG_PROFILE" in os.environ:
         debug_vendor_id = int(os.environ["RIVALCFG_PROFILE"].split(":")[0], 16)
-        debug_product_id = int(
-                os.environ["RIVALCFG_PROFILE"].split(":")[1], 16)
+        debug_product_id = int(os.environ["RIVALCFG_PROFILE"].split(":")[1], 16)
         profile = PROFILES[(debug_vendor_id, debug_product_id)]
         yield {
             "vendor_id": profile["vendor_id"],
             "product_id": profile["product_id"],
             "name": profile["name"],
-            }
+        }
     for profile in PROFILES.values():
-        if usbhid.is_device_plugged(
-                profile["vendor_id"], profile["product_id"]):
+        if usbhid.is_device_plugged(profile["vendor_id"], profile["product_id"]):
             yield {
-                    "vendor_id": profile["vendor_id"],
-                    "product_id": profile["product_id"],
-                    "name": profile["name"],
-                    }
+                "vendor_id": profile["vendor_id"],
+                "product_id": profile["product_id"],
+                "name": profile["name"],
+            }
 
 
 def get_profile(vendor_id=0x1038, product_id=None):
@@ -226,7 +231,8 @@ def get_profile(vendor_id=0x1038, product_id=None):
     profile_name = (vendor_id, product_id)
     if profile_name not in PROFILES:
         raise UnsupportedDevice(
-                "The requested device is not supported (%x:%x)" % profile_name)
+            "The requested device is not supported (%x:%x)" % profile_name
+        )
     return PROFILES[profile_name]
 
 
@@ -244,9 +250,7 @@ def _generate_profiles():
             continue
         for model in item.profile["models"]:
             profile = item.profile.copy()
-            profile_name = (
-                    model["vendor_id"],
-                    model["product_id"])
+            profile_name = (model["vendor_id"], model["product_id"])
             del profile["models"]
             for k, v in model.items():
                 if k == "override_defaults":
